# -*- coding: utf-8 -*-
"""
pyweblib - several modules for web programming tasks
(C) 1998-2015 by Michael Ströder <michael@stroeder.com>

This module including sub-modules is distributed under the terms
of the GPL (GNU GENERAL PUBLIC LICENSE) Version 2
(see http://www.gnu.org/copyleft/gpl.html)

Compability note:
requires Python 2.0+

Sub modules:
pyweblib.forms             class library for handling <FORM> input
pyweblib.session           server-side web session handling
pyweblib.helper            misc. stuff useful in CGI-BINs
pyweblib.sslenv            retrieves SSL-related env vars
pyweblib.httphelper        very basic HTTP functions
"""

# For the whole module-package
__version__ = '1.3.12'
__author__ = u'Michael Ströder'
__copyright__ = u'(C) 1998-2015 by Michael Ströder <michael@stroeder.com>'
__license__ = 'GPL (GNU GENERAL PUBLIC LICENSE) Version 2'

# File specific
__revision__ = '$Revision: 1.39 $'.split(' ')[1]
__info__ = '$Id: __init__.py,v 1.39 2015/01/10 16:37:13 michael Exp $'
